@@ -15,12 +15,12 @@
 #include "config-kontactinterface.h"
 #if KONTACTINTERFACE_HAVE_X11
 #include <KStartupInfo>
-
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
 #endif
+
+#ifdef Q_OS_WINDOWS
+#include <QFont>
+#include <Windows.h>
 #endif
 
 #include <QCommandLineParser>
@@ -72,6 +72,18 @@ PimUniqueApplication::PimUniqueApplication(int &argc, char **argv[])
     : QApplication(argc, *argv)
     , d(new PimUniqueApplicationPrivate())
 {
+#ifdef Q_OS_WINDOWS
+    if (AttachConsole(ATTACH_PARENT_PROCESS)) {
+        freopen("CONOUT$", "w", stdout);
+        freopen("CONOUT$", "w", stderr);
+    }
+
+    setStyle(QStringLiteral("breeze"));
+    QFont font(QStringLiteral("Segoe UI Emoji"));
+    font.setPointSize(10);
+    font.setHintingPreference(QFont::PreferNoHinting);
+    setFont(font);
+#endif
 }
 
 PimUniqueApplication::~PimUniqueApplication() = default;
@@ -179,3 +191,5 @@ int PimUniqueApplication::activate(const QStringList &arguments, const QString &
     Q_UNUSED(workingDirectory)
     return 0;
 }
+
+#include "moc_pimuniqueapplication.cpp"
